# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/OASISGui.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1040, 830)
        MainWindow.setMinimumSize(QtCore.QSize(1040, 830))
        MainWindow.setMaximumSize(QtCore.QSize(1040, 830))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setEnabled(False)
        self.tabWidget.setGeometry(QtCore.QRect(0, 320, 1050, 511))
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.groupBox = QtWidgets.QGroupBox(self.tab)
        self.groupBox.setGeometry(QtCore.QRect(10, 10, 351, 401))
        self.groupBox.setObjectName("groupBox")
        self.label_12 = QtWidgets.QLabel(self.groupBox)
        self.label_12.setGeometry(QtCore.QRect(10, 30, 181, 16))
        self.label_12.setObjectName("label_12")
        self.label_13 = QtWidgets.QLabel(self.groupBox)
        self.label_13.setGeometry(QtCore.QRect(10, 60, 181, 16))
        self.label_13.setObjectName("label_13")
        self.lineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.lineEdit.setGeometry(QtCore.QRect(200, 30, 131, 20))
        self.lineEdit.setObjectName("lineEdit")
        self.lineEdit_2 = QtWidgets.QLineEdit(self.groupBox)
        self.lineEdit_2.setGeometry(QtCore.QRect(200, 60, 131, 20))
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.groupBox_2 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_2.setGeometry(QtCore.QRect(10, 300, 331, 91))
        self.groupBox_2.setObjectName("groupBox_2")
        self.checkBox_3 = QtWidgets.QCheckBox(self.groupBox_2)
        self.checkBox_3.setGeometry(QtCore.QRect(10, 30, 231, 18))
        self.checkBox_3.setObjectName("checkBox_3")
        self.label_18 = QtWidgets.QLabel(self.groupBox_2)
        self.label_18.setEnabled(False)
        self.label_18.setGeometry(QtCore.QRect(10, 60, 161, 16))
        self.label_18.setObjectName("label_18")
        self.lineEdit_3 = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit_3.setEnabled(False)
        self.lineEdit_3.setGeometry(QtCore.QRect(190, 60, 131, 20))
        self.lineEdit_3.setObjectName("lineEdit_3")
        self.groupBox_11 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_11.setGeometry(QtCore.QRect(10, 120, 331, 171))
        self.groupBox_11.setObjectName("groupBox_11")
        self.comboBox_9 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_9.setEnabled(False)
        self.comboBox_9.setGeometry(QtCore.QRect(250, 140, 71, 22))
        self.comboBox_9.setObjectName("comboBox_9")
        self.label_24 = QtWidgets.QLabel(self.groupBox_11)
        self.label_24.setGeometry(QtCore.QRect(180, 110, 61, 16))
        self.label_24.setObjectName("label_24")
        self.comboBox_6 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_6.setEnabled(False)
        self.comboBox_6.setGeometry(QtCore.QRect(250, 50, 71, 22))
        self.comboBox_6.setObjectName("comboBox_6")
        self.comboBox_2 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_2.setEnabled(False)
        self.comboBox_2.setGeometry(QtCore.QRect(90, 50, 71, 22))
        self.comboBox_2.setObjectName("comboBox_2")
        self.label_23 = QtWidgets.QLabel(self.groupBox_11)
        self.label_23.setGeometry(QtCore.QRect(180, 80, 61, 16))
        self.label_23.setObjectName("label_23")
        self.label_17 = QtWidgets.QLabel(self.groupBox_11)
        self.label_17.setGeometry(QtCore.QRect(20, 140, 61, 16))
        self.label_17.setObjectName("label_17")
        self.label_25 = QtWidgets.QLabel(self.groupBox_11)
        self.label_25.setGeometry(QtCore.QRect(180, 50, 61, 16))
        self.label_25.setObjectName("label_25")
        self.label_14 = QtWidgets.QLabel(self.groupBox_11)
        self.label_14.setGeometry(QtCore.QRect(20, 50, 61, 16))
        self.label_14.setObjectName("label_14")
        self.comboBox_4 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_4.setEnabled(False)
        self.comboBox_4.setGeometry(QtCore.QRect(90, 110, 71, 22))
        self.comboBox_4.setObjectName("comboBox_4")
        self.comboBox_7 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_7.setEnabled(False)
        self.comboBox_7.setGeometry(QtCore.QRect(250, 80, 71, 22))
        self.comboBox_7.setObjectName("comboBox_7")
        self.label_16 = QtWidgets.QLabel(self.groupBox_11)
        self.label_16.setGeometry(QtCore.QRect(20, 110, 61, 16))
        self.label_16.setObjectName("label_16")
        self.label_15 = QtWidgets.QLabel(self.groupBox_11)
        self.label_15.setGeometry(QtCore.QRect(20, 80, 61, 16))
        self.label_15.setObjectName("label_15")
        self.comboBox_3 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_3.setEnabled(False)
        self.comboBox_3.setGeometry(QtCore.QRect(90, 80, 71, 22))
        self.comboBox_3.setObjectName("comboBox_3")
        self.comboBox_5 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_5.setEnabled(False)
        self.comboBox_5.setGeometry(QtCore.QRect(90, 140, 71, 22))
        self.comboBox_5.setObjectName("comboBox_5")
        self.comboBox_8 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_8.setEnabled(False)
        self.comboBox_8.setGeometry(QtCore.QRect(250, 110, 71, 22))
        self.comboBox_8.setObjectName("comboBox_8")
        self.label_26 = QtWidgets.QLabel(self.groupBox_11)
        self.label_26.setGeometry(QtCore.QRect(180, 140, 61, 16))
        self.label_26.setObjectName("label_26")
        self.label_30 = QtWidgets.QLabel(self.groupBox_11)
        self.label_30.setGeometry(QtCore.QRect(20, 22, 151, 16))
        self.label_30.setObjectName("label_30")
        self.comboBox_11 = QtWidgets.QComboBox(self.groupBox_11)
        self.comboBox_11.setEnabled(False)
        self.comboBox_11.setGeometry(QtCore.QRect(190, 20, 131, 22))
        self.comboBox_11.setObjectName("comboBox_11")
        self.label_29 = QtWidgets.QLabel(self.groupBox)
        self.label_29.setGeometry(QtCore.QRect(10, 90, 181, 16))
        self.label_29.setObjectName("label_29")
        self.comboBox_10 = QtWidgets.QComboBox(self.groupBox)
        self.comboBox_10.setGeometry(QtCore.QRect(200, 90, 131, 22))
        self.comboBox_10.setObjectName("comboBox_10")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_3.setGeometry(QtCore.QRect(380, 310, 421, 101))
        self.groupBox_3.setObjectName("groupBox_3")
        self.checkBox_4 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_4.setGeometry(QtCore.QRect(20, 30, 261, 18))
        self.checkBox_4.setChecked(True)
        self.checkBox_4.setObjectName("checkBox_4")
        self.checkBox_5 = QtWidgets.QCheckBox(self.groupBox_3)
        self.checkBox_5.setGeometry(QtCore.QRect(20, 60, 261, 18))
        self.checkBox_5.setObjectName("checkBox_5")
        self.pushButton_3 = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButton_3.setEnabled(False)
        self.pushButton_3.setGeometry(QtCore.QRect(260, 30, 151, 22))
        self.pushButton_3.setObjectName("pushButton_3")
        self.pushButton_4 = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButton_4.setEnabled(False)
        self.pushButton_4.setGeometry(QtCore.QRect(260, 60, 151, 22))
        self.pushButton_4.setObjectName("pushButton_4")
        self.pushButton_5 = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButton_5.setEnabled(False)
        self.pushButton_5.setGeometry(QtCore.QRect(490, 20, 151, 22))
        self.pushButton_5.setObjectName("pushButton_5")
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_4.setGeometry(QtCore.QRect(380, 10, 651, 291))
        self.groupBox_4.setObjectName("groupBox_4")
        self.textEdit = QtWidgets.QTextEdit(self.groupBox_4)
        self.textEdit.setGeometry(QtCore.QRect(10, 20, 631, 261))
        self.textEdit.setReadOnly(True)
        self.textEdit.setObjectName("textEdit")
        self.progressBar = QtWidgets.QProgressBar(self.tab)
        self.progressBar.setEnabled(False)
        self.progressBar.setGeometry(QtCore.QRect(10, 420, 1021, 31))
        self.progressBar.setAcceptDrops(False)
        self.progressBar.setStyleSheet("")
        self.progressBar.setMaximum(100)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setTextVisible(True)
        self.progressBar.setOrientation(QtCore.Qt.Horizontal)
        self.progressBar.setTextDirection(QtWidgets.QProgressBar.TopToBottom)
        self.progressBar.setObjectName("progressBar")
        self.progressBar_2 = QtWidgets.QProgressBar(self.tab)
        self.progressBar_2.setEnabled(False)
        self.progressBar_2.setGeometry(QtCore.QRect(10, 420, 981, 31))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.progressBar_2.sizePolicy().hasHeightForWidth())
        self.progressBar_2.setSizePolicy(sizePolicy)
        self.progressBar_2.setAcceptDrops(False)
        self.progressBar_2.setAutoFillBackground(False)
        self.progressBar_2.setStyleSheet("QProgressBar::chunk{background-color: red;}")
        self.progressBar_2.setMaximum(100)
        self.progressBar_2.setProperty("value", 100)
        self.progressBar_2.setTextVisible(False)
        self.progressBar_2.setObjectName("progressBar_2")
        self.groupBox_7 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_7.setGeometry(QtCore.QRect(820, 310, 211, 101))
        self.groupBox_7.setObjectName("groupBox_7")
        self.pushButton_2 = QtWidgets.QPushButton(self.groupBox_7)
        self.pushButton_2.setEnabled(False)
        self.pushButton_2.setGeometry(QtCore.QRect(10, 60, 191, 30))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.pushButton_2.setFont(font)
        self.pushButton_2.setObjectName("pushButton_2")
        self.pushButton_7 = QtWidgets.QPushButton(self.groupBox_7)
        self.pushButton_7.setEnabled(False)
        self.pushButton_7.setGeometry(QtCore.QRect(10, 20, 191, 30))
        font = QtGui.QFont()
        font.setPointSize(9)
        self.pushButton_7.setFont(font)
        self.pushButton_7.setObjectName("pushButton_7")
        self.groupBox_4.raise_()
        self.groupBox_3.raise_()
        self.groupBox.raise_()
        self.progressBar.raise_()
        self.progressBar_2.raise_()
        self.groupBox_7.raise_()
        self.tabWidget.addTab(self.tab, "")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(0, 20, 1041, 41))
        font = QtGui.QFont()
        font.setPointSize(20)
        self.label.setFont(font)
        self.label.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.label.setObjectName("label")
        self.comboBox = QtWidgets.QComboBox(self.centralwidget)
        self.comboBox.setEnabled(False)
        self.comboBox.setGeometry(QtCore.QRect(310, 80, 411, 22))
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setEnabled(True)
        self.pushButton.setGeometry(QtCore.QRect(740, 80, 121, 23))
        self.pushButton.setObjectName("pushButton")
        self.label_19 = QtWidgets.QLabel(self.centralwidget)
        self.label_19.setGeometry(QtCore.QRect(870, 70, 42, 42))
        self.label_19.setText("")
        self.label_19.setPixmap(QtGui.QPixmap(":/Misc/resources/spin.gif"))
        self.label_19.setScaledContents(True)
        self.label_19.setObjectName("label_19")
        self.groupBox_5 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_5.setEnabled(False)
        self.groupBox_5.setGeometry(QtCore.QRect(720, 140, 281, 171))
        self.groupBox_5.setObjectName("groupBox_5")
        self.checkBox_6 = QtWidgets.QCheckBox(self.groupBox_5)
        self.checkBox_6.setGeometry(QtCore.QRect(20, 30, 221, 21))
        self.checkBox_6.setObjectName("checkBox_6")
        self.radioButton = QtWidgets.QRadioButton(self.groupBox_5)
        self.radioButton.setEnabled(False)
        self.radioButton.setGeometry(QtCore.QRect(40, 100, 221, 20))
        self.radioButton.setChecked(True)
        self.radioButton.setObjectName("radioButton")
        self.radioButton_2 = QtWidgets.QRadioButton(self.groupBox_5)
        self.radioButton_2.setEnabled(False)
        self.radioButton_2.setGeometry(QtCore.QRect(40, 130, 221, 20))
        self.radioButton_2.setObjectName("radioButton_2")
        self.label_20 = QtWidgets.QLabel(self.groupBox_5)
        self.label_20.setEnabled(False)
        self.label_20.setGeometry(QtCore.QRect(20, 70, 131, 16))
        self.label_20.setObjectName("label_20")
        self.label_21 = QtWidgets.QLabel(self.groupBox_5)
        self.label_21.setEnabled(False)
        self.label_21.setGeometry(QtCore.QRect(220, 110, 41, 41))
        self.label_21.setText("")
        self.label_21.setPixmap(QtGui.QPixmap(":/Misc/resources/unlock.png"))
        self.label_21.setScaledContents(True)
        self.label_21.setObjectName("label_21")
        self.label_22 = QtWidgets.QLabel(self.centralwidget)
        self.label_22.setGeometry(QtCore.QRect(90, 5, 141, 131))
        self.label_22.setText("")
        self.label_22.setPixmap(QtGui.QPixmap("ui/resources/icons/128x128.png"))
        self.label_22.setObjectName("label_22")
        self.groupBox_6 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_6.setGeometry(QtCore.QRect(40, 140, 651, 171))
        self.groupBox_6.setObjectName("groupBox_6")
        self.label_28 = QtWidgets.QLabel(self.groupBox_6)
        self.label_28.setGeometry(QtCore.QRect(330, 20, 200, 14))
        self.label_28.setText("")
        self.label_28.setObjectName("label_28")
        self.checkBox = QtWidgets.QCheckBox(self.groupBox_6)
        self.checkBox.setEnabled(False)
        self.checkBox.setGeometry(QtCore.QRect(330, 120, 131, 18))
        self.checkBox.setObjectName("checkBox")
        self.label_11 = QtWidgets.QLabel(self.groupBox_6)
        self.label_11.setGeometry(QtCore.QRect(330, 100, 200, 14))
        self.label_11.setText("")
        self.label_11.setObjectName("label_11")
        self.label_6 = QtWidgets.QLabel(self.groupBox_6)
        self.label_6.setGeometry(QtCore.QRect(190, 100, 171, 16))
        self.label_6.setObjectName("label_6")
        self.label_9 = QtWidgets.QLabel(self.groupBox_6)
        self.label_9.setGeometry(QtCore.QRect(330, 60, 200, 14))
        self.label_9.setText("")
        self.label_9.setObjectName("label_9")
        self.label_27 = QtWidgets.QLabel(self.groupBox_6)
        self.label_27.setGeometry(QtCore.QRect(190, 20, 171, 16))
        self.label_27.setObjectName("label_27")
        self.label_4 = QtWidgets.QLabel(self.groupBox_6)
        self.label_4.setGeometry(QtCore.QRect(190, 60, 171, 16))
        self.label_4.setObjectName("label_4")
        self.checkBox_2 = QtWidgets.QCheckBox(self.groupBox_6)
        self.checkBox_2.setEnabled(False)
        self.checkBox_2.setGeometry(QtCore.QRect(330, 140, 251, 18))
        self.checkBox_2.setObjectName("checkBox_2")
        self.label_8 = QtWidgets.QLabel(self.groupBox_6)
        self.label_8.setGeometry(QtCore.QRect(330, 40, 200, 14))
        self.label_8.setText("")
        self.label_8.setObjectName("label_8")
        self.label_10 = QtWidgets.QLabel(self.groupBox_6)
        self.label_10.setGeometry(QtCore.QRect(330, 80, 200, 14))
        self.label_10.setText("")
        self.label_10.setObjectName("label_10")
        self.label_2 = QtWidgets.QLabel(self.groupBox_6)
        self.label_2.setGeometry(QtCore.QRect(40, 30, 111, 131))
        self.label_2.setText("")
        self.label_2.setPixmap(QtGui.QPixmap(":/Boards/resources/boards/Unknown.png"))
        self.label_2.setScaledContents(False)
        self.label_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_2.setObjectName("label_2")
        self.label_7 = QtWidgets.QLabel(self.groupBox_6)
        self.label_7.setGeometry(QtCore.QRect(190, 120, 171, 16))
        self.label_7.setObjectName("label_7")
        self.label_3 = QtWidgets.QLabel(self.groupBox_6)
        self.label_3.setGeometry(QtCore.QRect(190, 40, 171, 16))
        self.label_3.setObjectName("label_3")
        self.label_5 = QtWidgets.QLabel(self.groupBox_6)
        self.label_5.setGeometry(QtCore.QRect(190, 80, 171, 16))
        self.label_5.setObjectName("label_5")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menuBar = QtWidgets.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1040, 26))
        self.menuBar.setObjectName("menuBar")
        self.menuAbout = QtWidgets.QMenu(self.menuBar)
        self.menuAbout.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.menuAbout.setObjectName("menuAbout")
        self.menuFile = QtWidgets.QMenu(self.menuBar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menuBar)
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionSearch_Devices = QtWidgets.QAction(MainWindow)
        self.actionSearch_Devices.setObjectName("actionSearch_Devices")
        self.actionSerial_Sample = QtWidgets.QAction(MainWindow)
        self.actionSerial_Sample.setObjectName("actionSerial_Sample")
        self.actionDevice_Selected_Changed = QtWidgets.QAction(MainWindow)
        self.actionDevice_Selected_Changed.setObjectName("actionDevice_Selected_Changed")
        self.actionRange_Channel1_Changed = QtWidgets.QAction(MainWindow)
        self.actionRange_Channel1_Changed.setObjectName("actionRange_Channel1_Changed")
        self.actionshow_Previous_Data = QtWidgets.QAction(MainWindow)
        self.actionshow_Previous_Data.setObjectName("actionshow_Previous_Data")
        self.actionsave_Previous_Data = QtWidgets.QAction(MainWindow)
        self.actionsave_Previous_Data.setObjectName("actionsave_Previous_Data")
        self.actionLockDevice = QtWidgets.QAction(MainWindow)
        self.actionLockDevice.setObjectName("actionLockDevice")
        self.actionVoltageRangeAll = QtWidgets.QAction(MainWindow)
        self.actionVoltageRangeAll.setObjectName("actionVoltageRangeAll")
        self.actionResendData = QtWidgets.QAction(MainWindow)
        self.actionResendData.setObjectName("actionResendData")
        self.actionConvert_OASIS_Sample = QtWidgets.QAction(MainWindow)
        self.actionConvert_OASIS_Sample.setObjectName("actionConvert_OASIS_Sample")
        self.menuAbout.addAction(self.actionAbout)
        self.menuFile.addAction(self.actionConvert_OASIS_Sample)
        self.menuBar.addAction(self.menuFile.menuAction())
        self.menuBar.addAction(self.menuAbout.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.pushButton.clicked.connect(self.actionSearch_Devices.trigger) # type: ignore
        self.checkBox_3.toggled['bool'].connect(self.label_18.setEnabled) # type: ignore
        self.checkBox_3.toggled['bool'].connect(self.lineEdit_3.setEnabled) # type: ignore
        self.pushButton_2.clicked.connect(self.actionSerial_Sample.trigger) # type: ignore
        self.comboBox.currentIndexChanged['QString'].connect(self.actionDevice_Selected_Changed.trigger) # type: ignore
        self.comboBox_2.currentIndexChanged['QString'].connect(self.actionRange_Channel1_Changed.trigger) # type: ignore
        self.pushButton_3.clicked.connect(self.actionshow_Previous_Data.trigger) # type: ignore
        self.pushButton_4.clicked.connect(self.actionsave_Previous_Data.trigger) # type: ignore
        self.checkBox_6.toggled['bool'].connect(self.radioButton.setEnabled) # type: ignore
        self.checkBox_6.toggled['bool'].connect(self.radioButton_2.setEnabled) # type: ignore
        self.label_21.linkActivated['QString'].connect(self.actionLockDevice.trigger) # type: ignore
        self.comboBox_11.currentIndexChanged['QString'].connect(self.actionVoltageRangeAll.trigger) # type: ignore
        self.pushButton_7.clicked.connect(self.actionResendData.trigger) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "OASIS Control Panel"))
        self.groupBox.setTitle(_translate("MainWindow", "Data Acquisition Configuration"))
        self.label_12.setText(_translate("MainWindow", "Sample Time (s):"))
        self.label_13.setText(_translate("MainWindow", "Sampling Frequency (Hz):"))
        self.lineEdit.setText(_translate("MainWindow", "2"))
        self.lineEdit_2.setText(_translate("MainWindow", "10000"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Level Trigger"))
        self.checkBox_3.setText(_translate("MainWindow", "Enable Level Trigger"))
        self.label_18.setText(_translate("MainWindow", "Trigger Level (Channel 1):"))
        self.lineEdit_3.setText(_translate("MainWindow", "0.2"))
        self.groupBox_11.setTitle(_translate("MainWindow", "Voltage Ranges"))
        self.label_24.setText(_translate("MainWindow", "Ch. 7 (V):"))
        self.label_23.setText(_translate("MainWindow", "Ch. 6 (V):"))
        self.label_17.setText(_translate("MainWindow", "Ch. 4 (V):"))
        self.label_25.setText(_translate("MainWindow", "Ch. 5 (V):"))
        self.label_14.setText(_translate("MainWindow", "Ch. 1 (V):"))
        self.label_16.setText(_translate("MainWindow", "Ch. 3 (V):"))
        self.label_15.setText(_translate("MainWindow", "Ch. 2 (V):"))
        self.label_26.setText(_translate("MainWindow", "Ch. 8 (V):"))
        self.label_30.setText(_translate("MainWindow", "Set for all Channels (V):"))
        self.label_29.setText(_translate("MainWindow", "Oversampling Factor"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Postprocessing Options"))
        self.checkBox_4.setText(_translate("MainWindow", "Show Data Plots after sampling"))
        self.checkBox_5.setText(_translate("MainWindow", "Save Data as .mat file"))
        self.pushButton_3.setText(_translate("MainWindow", "Show Previous Data"))
        self.pushButton_4.setText(_translate("MainWindow", "Save Previous Data"))
        self.pushButton_5.setText(_translate("MainWindow", "Resend Previous Data"))
        self.groupBox_4.setTitle(_translate("MainWindow", "OASIS Device Log"))
        self.progressBar.setFormat(_translate("MainWindow", "%p%"))
        self.groupBox_7.setTitle(_translate("MainWindow", "Sample Control"))
        self.pushButton_2.setText(_translate("MainWindow", "Start Data Acquisition"))
        self.pushButton_7.setText(_translate("MainWindow", "Resend Previous Data"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Serial Data Acquisition"))
        self.label.setText(_translate("MainWindow", "<html><head/><body><p><span style=\" color:#0065bd;\">OASIS Control Panel</span></p></body></html>"))
        self.comboBox.setCurrentText(_translate("MainWindow", "Searching Devices..."))
        self.comboBox.setItemText(0, _translate("MainWindow", "Searching Devices..."))
        self.pushButton.setText(_translate("MainWindow", "Search Devices"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Wireless Sample Synchronization"))
        self.checkBox_6.setText(_translate("MainWindow", "Enable Synchronization"))
        self.radioButton.setText(_translate("MainWindow", "WSS Source"))
        self.radioButton_2.setText(_translate("MainWindow", "WSS Sink"))
        self.label_20.setText(_translate("MainWindow", "Selected device is:"))
        self.groupBox_6.setTitle(_translate("MainWindow", "Selected Device Information"))
        self.checkBox.setText(_translate("MainWindow", "TEDS Readout"))
        self.label_6.setText(_translate("MainWindow", "Installed ADC:"))
        self.label_27.setText(_translate("MainWindow", "Board Architecture:"))
        self.label_4.setText(_translate("MainWindow", "Hardware Version:"))
        self.checkBox_2.setText(_translate("MainWindow", "Wireless Sample Synchronization"))
        self.label_7.setText(_translate("MainWindow", "Hardware Features:"))
        self.label_3.setText(_translate("MainWindow", "Board Name:"))
        self.label_5.setText(_translate("MainWindow", "Firmware Version:"))
        self.menuAbout.setTitle(_translate("MainWindow", "Help"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionSearch_Devices.setText(_translate("MainWindow", "Search Devices"))
        self.actionSerial_Sample.setText(_translate("MainWindow", "Serial_Sample"))
        self.actionDevice_Selected_Changed.setText(_translate("MainWindow", "Device_Selected_Changed"))
        self.actionRange_Channel1_Changed.setText(_translate("MainWindow", "Range_Channel1_Changed"))
        self.actionshow_Previous_Data.setText(_translate("MainWindow", "show_Previous_Data"))
        self.actionsave_Previous_Data.setText(_translate("MainWindow", "save_Previous_Data"))
        self.actionLockDevice.setText(_translate("MainWindow", "LockDevice"))
        self.actionLockDevice.setToolTip(_translate("MainWindow", "LockDevice"))
        self.actionVoltageRangeAll.setText(_translate("MainWindow", "VoltageRangeAll"))
        self.actionVoltageRangeAll.setToolTip(_translate("MainWindow", "VoltageRangeAll"))
        self.actionResendData.setText(_translate("MainWindow", "ResendData"))
        self.actionConvert_OASIS_Sample.setText(_translate("MainWindow", "Convert OASIS Sample"))
import UI_resources_rc
